.error-page {
    text-align: center;
    line-height: 24px;
    color: #000000;
}

.error-display {
    font-size: 6rem;
    margin-bottom: 15px;
}

.error-text {
    font-size: 2rem;
    margin-bottom: .5rem;
}
