{% extends 'orchestra/base.html' %}
{% load staticfiles %}

{% block title %}Dashboard{% endblock %}

{% block main %}
<section id="main-content" ng-view autoscroll="true">
  {% block content %}content{% endblock content %}
</section>
{% endblock %}

{% block page_javascript %}
<script type="text/javascript">
    window.orchestra = {{ orchestra_arguments | safe }};
</script>

<script src="{% static "orchestra/common/js/lib/angular.min.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/js/lib/angular-route.min.js" %}" type="text/javascript"></script>
<script src="//ajax.googleapis.com/ajax/libs/angularjs/1.5.5/angular-sanitize.min.js"></script>
<script src="//cdnjs.cloudflare.com/ajax/libs/angular-ui-bootstrap/1.3.1/ui-bootstrap-tpls.min.js"></script>
<script src="//cdnjs.cloudflare.com/ajax/libs/moment.js/2.13.0/moment-with-locales.min.js"></script>
<script src="//cdnjs.cloudflare.com/ajax/libs/moment-timezone/0.5.3/moment-timezone-with-data.min.js"></script>
<script src="//cdnjs.cloudflare.com/ajax/libs/pikaday/1.4.0/pikaday.min.js" type="text/javascript"></script>
<script src="//cdnjs.cloudflare.com/ajax/libs/angular-ui-select/0.16.1/select.min.js" type="text/javascript"></script>

<script src="{% static "orchestra/common/js/orchestra.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/js/orchestra.config.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/js/orchestra.routes.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/js/orchestra.services.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/js/orchestra_api.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/js/orchestra.filters.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/components/checklist/lib/dragula/dragula.min.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/components/checklist/js/directives.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/components/quill/js/quill.min.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/components/quill/js/directives.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/components/iframe/js/directives.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/components/project_folder/project_folder.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/common/components/team_messages/team_messages.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/task/js/controllers.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/task/js/directives.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/task/js/autosave.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/task/js/required_fields.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/timing/time-entry.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/timing/service.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/timing/timecard/controller.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/timing/timecard/directives.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/timing/timer/directives.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/dashboard/js/controllers.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/dashboard/js/directives.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/lib/d3.min.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/controllers.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/data_service.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/crosshair.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/visUtils.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/tasksVis.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/assignmentsVis.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/iterationsVis.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/axis.js" %}" type="text/javascript"></script>
<script src="{% static "orchestra/project_management/js/projectVis.js" %}" type="text/javascript"></script>

{% for js in javascript_includes %}
  {# we call `static()` in the view function to prevent whitenoise looking for a template value #}
  {{ js | safe }}
{% endfor %}
{% endblock page_javascript%}

{% block page_stylesheets %}
    {# we call `static()` in the view function to prevent whitenoise looking for a template value #}
    {% for css in stylesheet_includes %}
      {{ css | safe }}
    {% endfor %}
{% endblock page_stylesheets%}
