/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select, .project-management .task-view .add-assignment, .project-management .task-view .worker-name, .project-management .project-actions {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

/**
 * Base stylesheet for Orchestra.
 *
 * This partial styles the base Django template and serves as the foundation for
 * each Orchestra view.
 */
html, body {
  font-size: 10px; }

section.wrapper {
  margin-top: 52px; }

section#main-content {
  margin-left: 0;
  color: #3c3c3c; }

header.header {
  background: #00598c;
  box-shadow: 0 1px 3px black;
  min-height: 0; }

h1, h2, h3, h4, h5, h6, p {
  margin: 0;
  padding: 0; }

a {
  color: #0079bf;
  text-decoration: none; }
  a:hover, a:focus, a:visited {
    color: #0079bf;
    text-decoration: underline; }

a.logo {
  font-size: 2rem;
  color: white;
  margin: 12px 30px; }
  a.logo:hover, a.logo:focus, a.logo:visited {
    color: white; }

.work-timer {
  float: right;
  height: 52px; }

#nav-options {
  cursor: pointer;
  font-size: 2rem;
  color: white;
  float: right;
  margin: 12px 30px;
  z-index: 1003; }
  #nav-options .dropdown-menu a {
    color: #0079bf; }
    #nav-options .dropdown-menu a:hover {
      color: #0079bf;
      text-decoration: underline; }

#hijacked-warning {
  left: 25%;
  width: 50%;
  border-radius: 0 0 5px 5px; }
  #hijacked-warning > span:last-child {
    margin-right: 0 !important; }

.section-panel {
  margin: 1.5rem;
  box-shadow: 0 1px 3px black;
  background-color: white; }
  .section-panel .section-header {
    margin-top: 0;
    color: white;
    background-color: #0079bf; }
    .section-panel .section-header h3 {
      margin: 1.3rem 0;
      font-size: 1.8rem; }
    .section-panel .section-header .btn {
      display: inline-block;
      color: white;
      background-color: #2ecc71; }
      .section-panel .section-header .btn:first-child {
        margin-left: 1.5rem; }
      .section-panel .section-header .btn:hover:not(.disabled) {
        border: 1px solid white; }
      .section-panel .section-header .btn.disabled {
        color: #cccccc;
        background-color: rgba(46, 204, 113, 0.6); }
  .section-panel .row:not(.section-header).padded > [class*="col-"] {
    padding-top: 1.5rem;
    padding-bottom: 1.5rem; }

.main-content {
  margin: 100px auto 0; }

/* Login/account-related pages */
.login-wrap {
  font-size: 1.3rem; }
  .login-wrap .error-non-field {
    padding: 0px 0px 10px 10px;
    color: red; }
  .login-wrap .error-field {
    padding: 5px 0px 0px 10px;
    color: red; }

/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select, .project-management .task-view .add-assignment, .project-management .task-view .worker-name, .project-management .project-actions {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

/**
 * Base stylesheet for Orchestra.
 *
 * This partial styles the base Django template and serves as the foundation for
 * each Orchestra view.
 */
html, body {
  font-size: 10px; }

section.wrapper {
  margin-top: 52px; }

section#main-content {
  margin-left: 0;
  color: #3c3c3c; }

header.header {
  background: #00598c;
  box-shadow: 0 1px 3px black;
  min-height: 0; }

h1, h2, h3, h4, h5, h6, p {
  margin: 0;
  padding: 0; }

a {
  color: #0079bf;
  text-decoration: none; }
  a:hover, a:focus, a:visited {
    color: #0079bf;
    text-decoration: underline; }

a.logo {
  font-size: 2rem;
  color: white;
  margin: 12px 30px; }
  a.logo:hover, a.logo:focus, a.logo:visited {
    color: white; }

.work-timer {
  float: right;
  height: 52px; }

#nav-options {
  cursor: pointer;
  font-size: 2rem;
  color: white;
  float: right;
  margin: 12px 30px;
  z-index: 1003; }
  #nav-options .dropdown-menu a {
    color: #0079bf; }
    #nav-options .dropdown-menu a:hover {
      color: #0079bf;
      text-decoration: underline; }

#hijacked-warning {
  left: 25%;
  width: 50%;
  border-radius: 0 0 5px 5px; }
  #hijacked-warning > span:last-child {
    margin-right: 0 !important; }

.section-panel {
  margin: 1.5rem;
  box-shadow: 0 1px 3px black;
  background-color: white; }
  .section-panel .section-header {
    margin-top: 0;
    color: white;
    background-color: #0079bf; }
    .section-panel .section-header h3 {
      margin: 1.3rem 0;
      font-size: 1.8rem; }
    .section-panel .section-header .btn {
      display: inline-block;
      color: white;
      background-color: #2ecc71; }
      .section-panel .section-header .btn:first-child {
        margin-left: 1.5rem; }
      .section-panel .section-header .btn:hover:not(.disabled) {
        border: 1px solid white; }
      .section-panel .section-header .btn.disabled {
        color: #cccccc;
        background-color: rgba(46, 204, 113, 0.6); }
  .section-panel .row:not(.section-header).padded > [class*="col-"] {
    padding-top: 1.5rem;
    padding-bottom: 1.5rem; }

.main-content {
  margin: 100px auto 0; }

.tasks-section .section-header .warning-message {
  font-style: italic;
  margin-left: 1.5rem;
  font-size: 1.5rem; }

.tasks-section .section-header .btn-new-task, .tasks-section .section-header .btn-new-entry-task, .tasks-section .section-header .btn-new-review-task {
  width: 150px;
  margin: 0 5px; }

.tasks-section .section-header .btn-new-entry-task {
  background-color: #27ae60; }
  .tasks-section .section-header .btn-new-entry-task.disabled {
    background-color: rgba(39, 174, 96, 0.6); }

.tasks-section .section-header .btn-new-review-task {
  background-color: #2ecc71; }
  .tasks-section .section-header .btn-new-review-task.disabled {
    background-color: rgba(46, 204, 113, 0.6); }

.tasks-section .col-task h4 {
  padding-bottom: 0.5rem;
  margin-bottom: 1.5rem;
  border-bottom: 2px solid #cccccc; }

.tasks-section .col-task.col-waiting {
  background-color: #eee;
  opacity: 0.6; }

.tasks-section .col-task .tasks-inactive {
  opacity: 0.6; }
  .tasks-section .col-task .tasks-inactive a, .tasks-section .col-task .tasks-inactive a:hover, .tasks-section .col-task .tasks-inactive a:focus, .tasks-section .col-task .tasks-inactive a:visited {
    pointer-events: none;
    cursor: default; }
  .tasks-section .col-task .tasks-inactive .task-card:hover {
    background-color: blue; }

.tasks-section .col-task .task-cards {
  min-height: 8.5rem; }
  .tasks-section .col-task .task-cards > div:not(:last-child) {
    margin-bottom: 1.5rem; }
    .tasks-section .col-task .task-cards > div:not(:last-child) [class*="col-"] {
      margin-bottom: 1.5rem; }
  .tasks-section .col-task .task-cards .task-card-wrapper {
    width: 100%;
    padding: 1rem;
    height: 8.5rem;
    text-align: left;
    background-color: white;
    position: relative;
    padding-left: 2.5rem;
    border: 0.1rem solid #cccccc; }
    .tasks-section .col-task .task-cards .task-card-wrapper:before {
      content: '';
      width: 1.5rem;
      position: absolute;
      top: -0.1rem;
      bottom: -0.1rem;
      left: -0.1rem;
      background: #0079bf; }
    .tasks-section .col-task .task-cards .task-card-wrapper:hover {
      background-color: rgba(230, 198, 55, 0.2); }
    .tasks-section .col-task .task-cards .task-card-wrapper a {
      color: #3c3c3c; }
      .tasks-section .col-task .task-cards .task-card-wrapper a:hover, .tasks-section .col-task .task-cards .task-card-wrapper a:visited, .tasks-section .col-task .task-cards .task-card-wrapper a:focus {
        color: #3c3c3c;
        text-decoration: none; }
      .tasks-section .col-task .task-cards .task-card-wrapper a .task-card {
        height: 6.5rem;
        overflow: hidden; }
        .tasks-section .col-task .task-cards .task-card-wrapper a .task-card .task-type h5 {
          text-transform: uppercase;
          color: #0079bf;
          width: 100%;
          font-size: 1.6em;
          margin: 5px 0;
          font-weight: bold; }
        .tasks-section .col-task .task-cards .task-card-wrapper a .task-card .task-detail {
          margin: 5px 0;
          font-size: 1.2em;
          line-height: 1.5em; }

.tasks-section .active-tasks {
  margin-top: 0; }
  @media (min-width: 992px) {
    .tasks-section .active-tasks .task-cards {
      min-height: 38.5rem; } }

.tasks-section .completed-tasks {
  padding-bottom: 1.5rem; }

/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select, .project-management .task-view .add-assignment, .project-management .task-view .worker-name, .project-management .project-actions {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

/* Confirmation modals */
.modal-confirm-submit {
  padding-top: 200px; }

.modal-confirm-header {
  border-top-left-radius: 5px;
  border-top-right-radius: 5px; }

.modal-header {
  background: #0079bf; }

.modal-confirm-body {
  overflow: auto;
  width: 300px; }
  .modal-confirm-body hr {
    margin: 0px 0px 3px 0px; }
  .modal-confirm-body .time-error-message {
    color: red;
    text-align: right;
    font-size: 1.2rem;
    padding-right: 9px; }
  .modal-confirm-body .time-question {
    margin-bottom: 3px; }
  .modal-confirm-body .time-summary {
    overflow: auto;
    padding-bottom: 3px; }
    .modal-confirm-body .time-summary .form-control {
      width: 30px;
      padding: 2px;
      height: 23px;
      text-align: right; }
    .modal-confirm-body .time-summary .time-label {
      float: left; }
    .modal-confirm-body .time-summary .time-report {
      float: right; }
      .modal-confirm-body .time-summary .time-report .time-unit-group {
        float: left;
        width: 70px; }
        .modal-confirm-body .time-summary .time-report .time-unit-group .time-value-float {
          width: 30px;
          overflow: auto;
          margin-right: 4px;
          float: left; }
          .modal-confirm-body .time-summary .time-report .time-unit-group .time-value-float .time-value {
            float: right;
            padding-right: 2px; }
        .modal-confirm-body .time-summary .time-report .time-unit-group .time-unit {
          font-size: 1.2rem; }

.modal-confirm-text {
  margin-bottom: 10px;
  font-size: 1.5rem; }

/* Fixed-location informational boxes */
.fixed-infobox-outer {
  margin: 20px auto;
  position: fixed;
  top: 160px;
  left: 0;
  right: 0;
  z-index: 1009; }

.fixed-infobox {
  display: block;
  text-align: center;
  width: 40%;
  margin: 0 auto;
  padding: 10px;
  border-radius: 5px; }

.save-message {
  display: inline-block;
  position: relative;
  left: 15px;
  color: white; }

.task-view {
  font-size: 1.5rem;
  position: relative; }
  .task-view .topbar-overview {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    font-size: 1.8rem;
    line-height: 2rem;
    background-color: #cccccc;
    box-shadow: 0 1px 3px #cccccc;
    color: #565656;
    height: 5rem; }
    .task-view .topbar-overview .topbar-leader {
      float: left;
      background-color: #565656;
      position: relative;
      color: white;
      z-index: 2; }
      .task-view .topbar-overview .topbar-leader .arrow-wrapper {
        position: absolute;
        right: -5rem; }
        .task-view .topbar-overview .topbar-leader .arrow-wrapper .arrow-with-shadow {
          width: 5rem;
          height: 5rem;
          position: relative;
          right: 0;
          overflow: hidden; }
        .task-view .topbar-overview .topbar-leader .arrow-wrapper .arrow-with-shadow:after {
          content: "";
          position: absolute;
          width: 3.53557rem;
          height: 3.53557rem;
          -webkit-transform: rotate(45deg);
          -ms-transform: rotate(45deg);
          -moz-transform: rotate(45deg);
          -o-transform: rotate(45deg);
          transform: rotate(45deg);
          top: 0.88389rem;
          left: -1.76778rem;
          box-shadow: 1px -1px 3px #bfbfbf;
          background-color: #565656; }
      .task-view .topbar-overview .topbar-leader .project-overview {
        padding: 1.5rem;
        margin-left: 3rem;
        background-color: #565656;
        float: left; }
        .task-view .topbar-overview .topbar-leader .project-overview .workflow {
          float: left;
          font-weight: bold;
          padding-right: 1.5rem; }
    .task-view .topbar-overview .topbar-follower {
      z-index: 1;
      padding-top: 1.5rem;
      padding-bottom: 1.5rem;
      float: left; }
      .task-view .topbar-overview .topbar-follower .task-overview {
        font-weight: bold;
        margin-left: 2.5rem;
        padding-left: 2.5rem; }
  .task-view .step-interface {
    margin-top: 8rem; }
  .task-view .reminders-title {
    padding: 10px 0;
    font-weight: bold; }
  .task-view .task-actions-wrapper {
    position: absolute;
    left: 0;
    right: 0;
    background-color: gray; }
    .task-view .task-actions-wrapper .task-actions {
      margin-left: 3rem;
      margin-right: 3rem;
      font-size: 1.3em; }
      .task-view .task-actions-wrapper .task-actions .btn {
        font-size: 1em; }
        .task-view .task-actions-wrapper .task-actions .btn:not(:first-child) {
          margin-left: 1.5rem; }
  .task-view .required-field-error.checkbox-error label {
    border-left: 2px solid red;
    overflow: auto;
    margin-bottom: 10px; }
  .task-view .required-field-error.text-error input {
    border: 1px solid red;
    box-shadow: 0px 0px 1px red inset; }

/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select, .project-management .task-view .add-assignment, .project-management .task-view .worker-name, .project-management .project-actions {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

.project-management-modal, .slack-modal, .data-modal, .revert-modal {
  font-size: 1.5rem;
  padding: 15px; }
  .project-management-modal .json-view, .slack-modal .json-view, .data-modal .json-view, .revert-modal .json-view {
    margin-top: 10px;
    max-height: 50vh; }

.slack-modal input {
  width: 200px; }

.slack-modal .add-user {
  cursor: pointer;
  color: #2ecc71; }

.slack-modal .remove-user {
  cursor: pointer;
  color: red; }

.data-modal .header-wrapper {
  overflow: auto; }
  .data-modal .header-wrapper .data-header {
    float: left; }
  .data-modal .header-wrapper .btn-admin {
    float: right; }

.revert-modal .header-wrapper {
  overflow: auto; }

.project-management {
  margin-top: 75px;
  font-size: 1.5rem;
  position: relative; }
  .project-management .project-description {
    font-size: 3rem;
    margin: 0 10px; }
  .project-management .axis-wrapper {
    position: relative;
    display: inline-block; }
  .project-management .axis {
    shape-rendering: crispEdges; }
    .project-management .axis.x line {
      stroke: #000; }
    .project-management .axis.x path {
      fill: none;
      stroke: #000; }
  .project-management .x.label {
    color: black;
    position: absolute; }
  .project-management svg {
    vertical-align: top;
    overflow: visible; }
  .project-management .task-view {
    position: relative;
    display: inline-block; }
    .project-management .task-view .add-assignment {
      display: block;
      cursor: pointer;
      text-align: right; }
    .project-management .task-view .worker-name {
      display: block;
      cursor: pointer;
      text-align: right;
      background-color: inherit; }
      .project-management .task-view .worker-name.readonly {
        outline: none;
        border: none; }
  .project-management .vis-wrapper {
    position: relative;
    margin-bottom: 75px; }
    .project-management .vis-wrapper .svg-wrapper {
      overflow-x: auto;
      overflow-y: hidden;
      position: relative; }
    .project-management .vis-wrapper .freeze-pane-left {
      position: absolute;
      top: 0;
      bottom: 0;
      left: 0;
      background-color: white;
      text-align: right;
      border-right: 1px solid #333;
      min-width: 225px; }
      .project-management .vis-wrapper .freeze-pane-left .scale-buttons {
        position: absolute;
        top: 0;
        right: 0;
        padding-right: 10px; }
      .project-management .vis-wrapper .freeze-pane-left .task-name {
        padding: 0 10px; }
        .project-management .vis-wrapper .freeze-pane-left .task-name .step-status {
          font-size: 0.8em; }
        .project-management .vis-wrapper .freeze-pane-left .task-name .task-action {
          margin-left: 5px; }
  .project-management .project-actions {
    display: inline-block;
    cursor: pointer; }
    .project-management .project-actions .project-actions-menu {
      font-size: 2em; }
  .project-management .task-rect {
    cursor: pointer; }

.error-page {
  text-align: center;
  line-height: 24px;
  color: #000000; }

.error-display {
  font-size: 6rem;
  margin-bottom: 15px; }

.error-text {
  font-size: 2rem;
  margin-bottom: .5rem; }

.timecard-view {
  position: absolute;
  top: 100px;
  width: 80%;
  max-width: 750px;
  left: 50%;
  transform: translateX(-50%);
  font-size: 1.4rem; }
  .timecard-view .date-picker {
    cursor: pointer; }
    .timecard-view .date-picker i {
      margin-right: 3px;
      color: #0079bf; }
  .timecard-view .help-icon {
    font-size: 3rem; }
  .timecard-view .incomplete {
    color: red; }
  .timecard-view .edit-label {
    display: block;
    font-size: 0.8em;
    font-weight: bold;
    text-transform: uppercase;
    margin-right: 5px; }
  .timecard-view .timecard-header {
    padding: 1.5rem; }
  .timecard-view .edit-tools {
    float: left; }
    .timecard-view .edit-tools i {
      margin-right: 5px;
      cursor: pointer; }
      .timecard-view .edit-tools i.active {
        color: #0079bf; }
  .timecard-view .day-name {
    display: block;
    padding-right: 1.5rem;
    text-align: right;
    font-size: 1.8rem;
    font-weight: bold;
    text-transform: uppercase; }
  .timecard-view .date-group {
    position: relative;
    padding: 0.75rem;
    margin: 0.75rem 0; }
    .timecard-view .date-group h2 {
      position: relative;
      font-size: 1.8rem;
      padding: 1.5rem;
      border-bottom: 1px solid #cccccc;
      background-color: white; }
      .timecard-view .date-group h2 .date-label {
        color: #27ae60;
        text-transform: uppercase;
        margin-right: 5px; }
      .timecard-view .date-group h2 .btn-add-entry {
        cursor: pointer;
        position: relative; }
        .timecard-view .date-group h2 .btn-add-entry:hover::after {
          content: 'New entry';
          position: absolute;
          top: 50%;
          right: 0px;
          padding: 5px;
          transform: translate(100%, -50%);
          text-transform: uppercase;
          font-weight: bold;
          font-size: 0.6em;
          font-family: "Ruda", sans-serif; }
      .timecard-view .date-group h2 .date-duration {
        float: right;
        display: inline-block;
        vertical-align: bottom; }
  .timecard-view .entry-row {
    position: relative;
    background-color: white;
    box-sizing: border-box;
    padding: 1.5rem;
    background-color: white; }
    .timecard-view .entry-row.gray-stripe {
      background-color: rgba(204, 204, 204, 0.5); }
    .timecard-view .entry-row .row {
      padding: 5px 0; }
    .timecard-view .entry-row .description input {
      width: 100%; }
    .timecard-view .entry-row .edit-time {
      text-align: right; }
      .timecard-view .entry-row .edit-time label {
        margin: 0; }
      .timecard-view .entry-row .edit-time .time-component {
        display: inline-block;
        text-align: center; }
    .timecard-view .entry-row .edit-task {
      float: left;
      width: 300px; }
      .timecard-view .entry-row .edit-task .ui-select-bootstrap > .ui-select-choices {
        width: auto; }
    .timecard-view .entry-row .edit-options {
      float: right; }
      .timecard-view .entry-row .edit-options .edit-cancel-handle {
        cursor: pointer;
        display: inline-block; }
        .timecard-view .entry-row .edit-options .edit-cancel-handle:hover {
          text-decoration: underline; }
    .timecard-view .entry-row .form-cell:not(:last-of-type) {
      padding-right: 10px; }
    .timecard-view .entry-row:hover input:read-only, .timecard-view .entry-row.editing input:read-only {
      background: white; }
  .timecard-view .time-input {
    width: 55px; }
  .timecard-view .show-description {
    font-size: 1rem;
    color: #0079bf;
    cursor: pointer; }

.account-settings a:hover, .account-settings a:focus, .account-settings a:visited {
  color: #FFF;
  text-decoration: none; }

.account-settings .row:not(:last-child) {
  margin-bottom: 15px; }

.account-settings .account-tabs {
  position: relative;
  z-index: 3; }
  .account-settings .account-tabs .btn {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0; }
    .account-settings .account-tabs .btn.selected, .account-settings .account-tabs .btn:hover {
      color: #2a6496;
      background-color: white;
      border-color: white; }

.account-settings .communication-methods ul {
  padding: 5px 0px 0px 0px; }

.account-settings .communication-methods ul p label {
  font-size: 13px;
  font-weight: normal;
  letter-spacing: normal;
  line-height: inherit; }

.account-settings .card {
  position: relative;
  z-index: 2;
  padding: 50px;
  background: #FFFFFF;
  box-shadow: 0px 17px 25px 0px rgba(104, 104, 104, 0.04), 0px 0px 55px 0px rgba(219, 219, 219, 0.28);
  height: auto; }

.account-settings .account-actions {
  margin-top: 15px;
  text-align: right; }

.account-settings label {
  font-size: 14px;
  font-weight: 600;
  letter-spacing: 1.59px;
  line-height: 26px; }

.account-settings input[type=checkbox] {
  height: inherit;
  width: auto;
  display: inline-block;
  margin-left: 3px;
  margin-right: 5px; }

.account-settings #id_phone_0, .account-settings #id_phone_1 {
  display: inline; }

.account-settings #id_phone_0 {
  width: 29%;
  margin-right: 1%; }

.account-settings #id_phone_1 {
  width: 70%; }

.communication-container {
  text-align: center; }
  .communication-container .card {
    padding-top: 80px; }
  .communication-container a {
    color: #FFF; }
  .communication-container .spaced {
    padding-top: 15px; }
