/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select, .checklist-wrapper .toggle-completed, li.checklist-item .line-item .item-title input[type="text"].readonly, .new-item .line-item .item-title input[type="text"].readonly, li.checklist-item .item-tools, .new-item .item-tools {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

.checklist-wrapper {
  width: 100%;
  padding: 15px; }
  .checklist-wrapper .toggle-completed {
    display: inline-block;
    color: #0079bf;
    cursor: pointer;
    padding: 10px 0; }
    .checklist-wrapper .toggle-completed:hover {
      font-weight: bold; }
  .checklist-wrapper .new-item {
    color: white;
    cursor: pointer;
    margin-bottom: 15px;
    border: none;
    background-color: #27ae60; }
    .checklist-wrapper .new-item:hover {
      background-color: #2ecc71; }
    .checklist-wrapper .new-item .line-item .new-item-button {
      float: left;
      height: 30px;
      width: 30px;
      font-size: 22px;
      text-align: center;
      margin-left: 2px; }
    .checklist-wrapper .new-item .line-item .new-item-text {
      height: 30px;
      margin-left: 3px;
      margin-top: 5px; }
    .checklist-wrapper .new-item:hover {
      text-decoration: underline; }
  .checklist-wrapper ul.checklist {
    list-style: none;
    padding: 0;
    margin: 0; }

li.checklist-item, .new-item {
  list-style: none;
  background-color: white;
  position: relative;
  margin-bottom: 0;
  border: 1px solid #ccc;
  box-shadow: none;
  padding: 7px;
  height: auto;
  margin-top: -1px;
  opacity: 1;
  -webkit-transition: all 1s;
  -ms-transition: all 1s;
  -moz-transition: all 1s;
  -o-transition: all 1s;
  transition: all 1s; }
  li.checklist-item.item-hidden, .new-item.item-hidden {
    -webkit-transition: all 1s;
    -ms-transition: all 1s;
    -moz-transition: all 1s;
    -o-transition: all 1s;
    transition: all 1s;
    height: 0;
    padding: 0;
    margin-top: 0;
    opacity: 0;
    border: 0; }
    li.checklist-item.item-hidden.item-expanded, .new-item.item-hidden.item-expanded {
      margin: 0; }
  li.checklist-item.item-expanded, .new-item.item-expanded {
    -webkit-transition: all 0.5s;
    -ms-transition: all 0.5s;
    -moz-transition: all 0.5s;
    -o-transition: all 0.5s;
    transition: all 0.5s;
    margin-top: 5px;
    margin-bottom: 20px; }
  li.checklist-item .item-description, .new-item .item-description {
    -webkit-transition: all 0.5s;
    -ms-transition: all 0.5s;
    -moz-transition: all 0.5s;
    -o-transition: all 0.5s;
    transition: all 0.5s;
    opacity: 0;
    height: 0;
    margin-bottom: 0;
    margin-left: 30px;
    margin-right: 75px;
    overflow: hidden; }
    li.checklist-item .item-description.expanded, .new-item .item-description.expanded {
      -webkit-transition: all 0.5s;
      -ms-transition: all 0.5s;
      -moz-transition: all 0.5s;
      -o-transition: all 0.5s;
      transition: all 0.5s;
      opacity: 1;
      height: auto;
      min-height: 100px;
      margin-top: 10px;
      margin-bottom: 10px;
      padding-left: 10px; }
      li.checklist-item .item-description.expanded .comment, .new-item .item-description.expanded .comment {
        position: relative;
        margin-top: -1px; }
        li.checklist-item .item-description.expanded .comment:first-child, .new-item .item-description.expanded .comment:first-child {
          margin-top: 0; }
        li.checklist-item .item-description.expanded .comment:last-child, .new-item .item-description.expanded .comment:last-child {
          margin-top: 10px; }
        li.checklist-item .item-description.expanded .comment .orchestra-quill-wrapper, .new-item .item-description.expanded .comment .orchestra-quill-wrapper {
          box-shadow: none;
          border: 1px solid #ccc; }
          li.checklist-item .item-description.expanded .comment .orchestra-quill-wrapper .orchestra-quill-editor, .new-item .item-description.expanded .comment .orchestra-quill-wrapper .orchestra-quill-editor {
            min-height: 150px;
            height: auto; }
          li.checklist-item .item-description.expanded .comment .orchestra-quill-wrapper.readonly .orchestra-quill-editor, .new-item .item-description.expanded .comment .orchestra-quill-wrapper.readonly .orchestra-quill-editor {
            min-height: 0;
            margin-top: 15px; }
          li.checklist-item .item-description.expanded .comment .orchestra-quill-wrapper .orchestra-quill-toolbar, .new-item .item-description.expanded .comment .orchestra-quill-wrapper .orchestra-quill-toolbar {
            margin-top: 0;
            border-top: none; }
        li.checklist-item .item-description.expanded .comment .comment-meta, .new-item .item-description.expanded .comment .comment-meta {
          font-size: 10px;
          position: absolute;
          top: 15px;
          left: 15px;
          right: 15px; }
          li.checklist-item .item-description.expanded .comment .comment-meta .comment-author, .new-item .item-description.expanded .comment .comment-meta .comment-author {
            float: left; }
          li.checklist-item .item-description.expanded .comment .comment-meta .comment-timestamp, .new-item .item-description.expanded .comment .comment-meta .comment-timestamp {
            float: right; }
        li.checklist-item .item-description.expanded .comment .add-comment, .new-item .item-description.expanded .comment .add-comment {
          color: #27ae60; }
  li.checklist-item .line-item, .new-item .line-item {
    overflow: hidden;
    position: relative;
    height: 30px;
    width: 100%;
    cursor: pointer; }
    li.checklist-item .line-item .item-title, .new-item .line-item .item-title {
      position: absolute;
      top: 0;
      bottom: 0;
      left: 30px;
      right: 75px;
      padding: 0 10px; }
      li.checklist-item .line-item .item-title input[type="text"], .new-item .line-item .item-title input[type="text"] {
        box-sizing: content-box;
        max-width: 100%;
        height: 26px;
        outline: none;
        border: 1px solid #0079bf;
        -webkit-transition: border 0.5s;
        -ms-transition: border 0.5s;
        -moz-transition: border 0.5s;
        -o-transition: border 0.5s;
        transition: border 0.5s; }
        li.checklist-item .line-item .item-title input[type="text"].readonly, .new-item .line-item .item-title input[type="text"].readonly {
          cursor: text;
          border: 1px solid white; }
    li.checklist-item .line-item input[type="checkbox"], .new-item .line-item input[type="checkbox"] {
      display: none; }
    li.checklist-item .line-item label, .new-item .line-item label {
      -webkit-transition: all 0.5s;
      -ms-transition: all 0.5s;
      -moz-transition: all 0.5s;
      -o-transition: all 0.5s;
      transition: all 0.5s;
      position: absolute;
      top: 0;
      left: 0;
      height: 30px;
      width: 30px;
      margin: 0;
      color: white;
      cursor: pointer;
      border: 1px solid #0079bf;
      box-shadow: inset 0 0 1px #0079bf; }
      li.checklist-item .line-item label.checked, .new-item .line-item label.checked {
        -webkit-transition: all 0.5s;
        -ms-transition: all 0.5s;
        -moz-transition: all 0.5s;
        -o-transition: all 0.5s;
        transition: all 0.5s;
        background-color: #0079bf; }
      li.checklist-item .line-item label i, .new-item .line-item label i {
        -webkit-transition: all 0.5s;
        -ms-transition: all 0.5s;
        -moz-transition: all 0.5s;
        -o-transition: all 0.5s;
        transition: all 0.5s;
        visibility: hidden; }
      li.checklist-item .line-item label.checked i, .new-item .line-item label.checked i {
        -webkit-transition: all 0.5s;
        -ms-transition: all 0.5s;
        -moz-transition: all 0.5s;
        -o-transition: all 0.5s;
        transition: all 0.5s;
        visibility: visible; }
      li.checklist-item .line-item label i, .new-item .line-item label i {
        font-size: 22px;
        position: absolute;
        top: 3px;
        left: 3px; }
  li.checklist-item .item-tools, .new-item .item-tools {
    position: absolute;
    right: 75px; }
    li.checklist-item .item-tools .tool, li.checklist-item .item-tools .expand-toggle, li.checklist-item .item-tools .edit-toggle, li.checklist-item .item-tools .item-remove, .new-item .item-tools .tool, .new-item li.checklist-item .item-tools .expand-toggle, li.checklist-item .new-item .item-tools .expand-toggle, .new-item .item-tools .expand-toggle, .new-item li.checklist-item .item-tools .edit-toggle, li.checklist-item .new-item .item-tools .edit-toggle, .new-item .item-tools .edit-toggle, .new-item li.checklist-item .item-tools .item-remove, li.checklist-item .new-item .item-tools .item-remove, .new-item .item-tools .item-remove {
      width: 25px;
      text-align: center;
      position: absolute;
      top: 5px; }
    li.checklist-item .item-tools .expand-toggle, .new-item .item-tools .expand-toggle {
      left: 0;
      cursor: pointer; }
      li.checklist-item .item-tools .expand-toggle.selected, .new-item .item-tools .expand-toggle.selected {
        color: #0079bf; }
    li.checklist-item .item-tools .edit-toggle, .new-item .item-tools .edit-toggle {
      left: 25px;
      cursor: pointer; }
      li.checklist-item .item-tools .edit-toggle.selected, .new-item .item-tools .edit-toggle.selected {
        color: #0079bf; }
    li.checklist-item .item-tools .item-remove, .new-item .item-tools .item-remove {
      left: 50px;
      cursor: pointer;
      color: red; }
