{% extends 'registration/registration_base.html' %}

{% block title %}Registration complete{% endblock %}

{% block registration_block %}
    Your registration is complete. Please wait for an email with the activation link.
{% endblock registration_block %}
